@@ -219,6 +219,15 @@ class PDFViewer(ContextualViewer):
         self.doc = PDFDocument(fobj, password=password)
         super(PDFViewer, self).__init__(None, Resources(), self.graphics_state_stack_class())
 
+    @property
+    def metadata(self):
+        """
+        Returns document metadata from file's trailer info dict
+
+        :return: dict, if metadata exists `None` otherwise.
+        """
+        return self.doc.metadata
+
     @property
     def current_page(self):
         """ :return: Current :class:`~pdfreader.types.objects.Page` instance """
